program MWconnP;

{$APPTYPE CONSOLE}

{%File 'MWconnU.inc'}
{%File 'MWconnU1.inc'}
{%File 'MWconnU2.inc'}

uses
  Windows,
  SysUtils,
  MWconnU;

function GetModeOnNumber(const aNumber : LongInt) : String;
begin
  case aNumber of
    1 : Result := 'GPRS';
    2 : Result := 'UMTS';
  else
    Result := 'Unbekannt';
  end;
end;

var
  vAccessMode : TAccessMode;
  vBufferA    : THandle;
  vBufferB    : PMWconnIO;
  vNextLine   : String;
  vTemp       : String;

const
  cExitCommand = 'QUIT';
  cFirstChar   = ':';
  cStatCommand = 'STAT';

begin
  WriteLn(cName + ' ' + cVersion + ' [' + cReleaseName + ' (' + cReleaseDate + ')' + ']');
  WriteLn('(C) ' + cCopyrightYear + ' ' + cCopyrightOwner);
  WriteLn('');

  vAccessMode := OpenMWconnIO(vBufferA, vBufferB);
  try
    WriteLn('');
    Write('Access Mode: ');
    case vAccessMode of
      amAll   : WriteLn('ALL');
      amRead  : WriteLn('READ');
      amWrite : WriteLn('WRITE');
    else
      WriteLn('NONE');
    end;
    WriteLn('');
    WriteLn('Commands available:');
    WriteLn('  QUIT - close application');
    if (vAccessMode <> amNone) then
      WriteLn('  STAT - print connection statistics');
    WriteLn('');

    repeat
      Write('> ');
      ReadLn(vNextLine);
      WriteLn('');

      if (Trim(vNextLine) <> '') then
      begin
        if (AnsiLowerCase(vNextLine) = AnsiLowerCase(cStatCommand)) then
        begin
          if (vAccessMode <> amNone) then
          begin
            try
              WriteLn('Laenge der Struktur: ' + IntToStr(vBufferB^.Len));
              WriteLn('Strukturversion    : ' + IntToStr(vBufferB^.Structure_Version));
              WriteLn('Programmversion    : ' + IntToStr(vBufferB^.Program_Version shr 8) + '.' + IntToStr(vBufferB^.Program_Version and 255));
              WriteLn('Prozesszaehler     : ' + IntToStr(vBufferB^.Process_Counter));
              WriteLn('');
              WriteLn('Summiertes Datenvolumen: ' + IntToStr(vBufferB^.Volume) + ' kBytes');
              WriteLn('Summierte Onlinezeit   : ' + IntToStr(vBufferB^.Time) + ' Minuten');
              WriteLn('');
              WriteLn('Aktuelle Onlinezeit        : ' + IntToStr(vBufferB^.Online_Time) + ' Sekunden');
              WriteLn('Aktuelle/Letzte Offlinezeit: ' + IntToStr(vBufferB^.Offline_Time) + ' Sekunden');
              WriteLn('');
              WriteLn('Upspeed  : ' + FloatToStr(vBufferB^.UpSpeed / 1000) + ' kBytes/s');
              WriteLn('Downspeed: ' + FloatToStr(vBufferB^.DownSpeed / 1000) + ' kBytes/s');
              WriteLn('');
              WriteLn('Betriebsart  : ' + IntToStr(vBufferB^.OpMode) + ' (' + GetModeOnNumber(vBufferB^.OpMode) + ')');
              WriteLn('Signalstaerke: ' + IntToStr(vBufferB^.Signal_Raw) + ' = ' + IntToStr(vBufferB^.Signal_Percent) + '% = ' + IntToStr(vBufferB^.Signal_DBM) + ' DBM');
              WriteLn('');
              WriteLn('Netzname: ' + String(vBufferB^.Network_Name));
              WriteLn('PLMN    : ' + String(vBufferB^.PLMN));
              WriteLn('LAC     : ' + String(vBufferB^.LAC));
              WriteLn('Cell-ID : ' + String(vBufferB^.CID));
              WriteLn('');
              WriteLn('Meldung      : ' + String(vBufferB^.Message));
              WriteLn('Mini-Meldung : ' + String(vBufferB^.Mini_Message));
              WriteLn('Fehlermeldung: ' + String(vBufferB^.Error_Message));
            except
              WriteLn('An error has occurred.');
              WriteLn('Probably you do not have READ access.');
            end;
          end
          else
          begin
            WriteLn('The execution has been denied.');
            WriteLn('You do not have READ access.');
          end;
        end
        else
        begin
          if (AnsiLowerCase(vNextLine) <> AnsiLowerCase(cExitCommand)) then
          begin
            if ((vAccessMode = amWrite) or (vAccessMode = amAll)) then
            begin
              try
                vBufferB^.Answer := '';

                CopyMemory(@vBufferB^.Command[0], @vNextLine[1], Length(vNextLine));
                vBufferB^.Command[Length(vNextLine)] := #0;

                if (Pos(cFirstChar, vNextLine) = 1) then
                begin
                  vTemp := vBufferB^.Answer;

                  while (vBufferB^.Answer = '') do
                    Sleep(100);
                end;

                WriteLn(vBufferB^.Answer);
              except
                WriteLn('An error has occurred.');
                WriteLn('Probably you do not have WRITE access.');
              end;
            end
            else
            begin
              WriteLn('The execution has been denied.');
              WriteLn('You do not have WRITE access.');
            end;
          end;
        end;

        WriteLn('');
      end;
    until (AnsiLowerCase(vNextLine) = AnsiLowerCase(cExitCommand));
  finally
    if (vAccessMode <> amNone) then
      CloseMWconnIO(vBufferA, vBufferB);
  end;
end.
